==> qtjambi-qt3dcore-6.5.3-sources.jar: io/qt/qt3d/core/QAbstractSkeleton.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>A skeleton contains the joints for a skinned mesh</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3dcore-qabstractskeleton.html">Qt3DCore::QAbstractSkeleton</a></code></p>
 */
public class QAbstractSkeleton extends io.qt.qt3d.core.QNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractSkeleton.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3dcore-qabstractskeleton.html#jointCount-prop">Qt3DCore::QAbstractSkeleton::<wbr>jointCountChanged(int)</a></code></p>
     */
    @QtPropertyNotify(name="jointCount")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Integer> jointCountChanged = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3dcore-qabstractskeleton.html#jointCount-prop">Qt3DCore::QAbstractSkeleton::<wbr>jointCount()const</a></code></p>
     */
    @QtPropertyReader(name="jointCount")
    @QtUninvokable
    public final int jointCount(){
        return jointCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int jointCount_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QAbstractSkeleton(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Kotlin property getter. In Java use {@link #jointCount()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final int getJointCount() {
        return jointCount();
    }
}

==> qtjambi-qt3dcore-6.5.5-sources.jar: io/qt/qt3d/core/QAbstractSkeleton.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>A skeleton contains the joints for a skinned mesh</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3dcore-qabstractskeleton.html">Qt3DCore::QAbstractSkeleton</a></code></p>
 */
public class QAbstractSkeleton extends io.qt.qt3d.core.QNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractSkeleton.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3dcore-qabstractskeleton.html#jointCount-prop">Qt3DCore::QAbstractSkeleton::<wbr/>jointCountChanged(int)</a></code></p>
     */
    @QtPropertyNotify(name="jointCount")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Integer> jointCountChanged = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3dcore-qabstractskeleton.html#jointCount-prop">Qt3DCore::QAbstractSkeleton::<wbr/>jointCount()const</a></code></p>
     */
    @QtPropertyReader(name="jointCount")
    @QtUninvokable
    public final int jointCount(){
        return jointCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int jointCount_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QAbstractSkeleton(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #jointCount()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final int getJointCount() {
        return jointCount();
    }
}
